@@ -1,4 +1,4 @@
-"""This module provides the ConstantExpression class to represent constant expressions.
+"""This module provides the ConstantDomainExpression class to represent constant expressions.
 
 Copyright 2014--2020 Michael Hayes, UCECE
 
@@ -13,11 +13,11 @@ from .admittancemixin import AdmittanceMixin
 from .impedancemixin import ImpedanceMixin
 from .transfermixin import TransferMixin
 
-class ConstantExpression(ConstantDomain, Expr):
+class ConstantDomainExpression(ConstantDomain, Expr):
     """Constant real expression or symbol.
 
     If symbols in the expression are known to be negative, use
-    ConstantExpression(expr, positive=False)
+    ConstantDomainExpression(expr, positive=False)
 
     """
 
@@ -30,13 +30,14 @@ class ConstantExpression(ConstantDomain, Expr):
                     'constant expression %s cannot depend on %s' % (val, symbol))
 
         assumptions['dc'] = True        
-        super(ConstantExpression, self).__init__(val, **assumptions)
+        super(ConstantDomainExpression, self).__init__(val, **assumptions)
 
     def as_expr(self):
-        return ConstantExpression(self)
-        
+        return ConstantDomainExpression(self)
+
     def rms(self):
-        return {ConstantVoltage: TimeDomainVoltage, ConstantCurrent : TimeDomainCurrent}[self.__class__](self)
+        """Return root mean square."""
+        return self
 
     def fourier(self):
         """Convert to Fourier domain representation."""
@@ -65,11 +66,11 @@ class ConstantExpression(ConstantDomain, Expr):
         return self.time().laplace()    
     
 
-class ConstantTimeExpression(ConstantExpression):
+class ConstantTimeDomainExpression(ConstantDomainExpression):
     pass
     
 
-class ConstantFrequencyExpression(ConstantExpression):
+class ConstantFrequencyDomainExpression(ConstantDomainExpression):
 
     def laplace(self, **assumptions):
         return self.change(self, domain='laplace', **assumptions)
@@ -80,53 +81,18 @@ class ConstantFrequencyExpression(ConstantExpression):
         return self.laplace(**assumptions).time(**assumptions)        
 
     
-class ConstantVoltage(VoltageMixin, ConstantTimeExpression):
-    """This is considered a constant time-domain expression."""
-
-    def cpt(self):
-        from .oneport import Vdc
-        return Vdc(self)
-
-    
-class ConstantCurrent(CurrentMixin, ConstantTimeExpression):
-    """This is considered a constant time-domain expression."""    
-
-    def cpt(self):
-        from .oneport import Idc
-        return Idc(self)
-
-    
-class ConstantImpedance(ImpedanceMixin, ConstantFrequencyExpression):
-    """This is considered a constant Laplace-domain expression."""
-    pass
-
-    
-class ConstantAdmittance(AdmittanceMixin, ConstantFrequencyExpression):
-    """This is considered a constant Laplace-domain expression."""    
-    pass
-
-
-class ConstantTransferFunction(TransferMixin, ConstantFrequencyExpression):
-    """This is considered a constant Laplace-domain expression."""    
-    pass
-
-
 def cexpr(arg, **assumptions):
-    """Create Lcapy constant expression from arg."""
+    """Create Lcapy constant expression from `arg`.
 
-    return ConstantExpression(arg)
+    By default, `arg` is assumed to be positive.  If symbols in the
+    `arg` are known to be negative, use `cexpr(arg, positive=False)`.
+
+    """
+
+    return ConstantDomainExpression(arg)
 
 
 from .expressionclasses import expressionclasses
 
-classes = expressionclasses.make(ConstantExpression)
-
-classes['voltage'] = ConstantVoltage
-classes['current'] = ConstantCurrent
-classes['admittance'] = ConstantAdmittance
-classes['impedance'] = ConstantImpedance
-classes['transfer'] = ConstantTransferFunction
-expressionclasses.add('constant', classes)
-
-from .texpr import t, TimeDomainCurrent, TimeDomainVoltage, TimeDomainExpression
-from .sexpr import s, LaplaceDomainExpression
+expressionclasses.register('constant', ConstantTimeDomainExpression, ConstantFrequencyDomainExpression,
+                           ('voltage', 'current', 'voltagesquared', 'currentsquared'))
