@@ -29,7 +29,8 @@ pretty_expr_map = {sym.I: junicode, sym.Heaviside: 'u'}
 functions = ('heaviside', 'diracdelta', 'conjugate', 'sqrt', 'exp',
              'log', 'log10', 'sin', 'cos', 'tan', 'cot' 'asin',
              'acos', 'atan', 'atan2', 'acot', 'sinh', 'cosh', 'tanh', 'asinh',
-             'acosh', 'atanh', 'gcd', 'abs', 'unitimpulse', 'arg', 'sign')
+             'acosh', 'atanh', 'gcd', 'abs', 'unitimpulse', 'arg', 'sign',
+             'rect', 'sinc')
 
 subscripts = ('in', 'out', 'ref', 'rms', 'load', 'source', 'avg',
               'mean', 'peak', 'pk', 'pk-pk', 'pp', 'min', 'max', 'src', 'bat',
@@ -51,3 +52,6 @@ except:
     
 matrix_inverse_fallback_method = 'ADJ'
 
+use_units = False
+
+abbreviate_units = True
