@@ -27,14 +27,14 @@ class Domain(object):
 
 class UndefinedDomain(Domain):
     domain = 'undefined'
-    domain_label = ''
+    domain_label = 'Undefined'
     domain_units = ''
     is_undefined_domain = True
 
 
 class ConstantDomain(Domain):    
     domain = 'constant'
-    domain_label = ''    
+    domain_label = 'Constant'    
     domain_units = ''
     is_constant_domain = True
     
@@ -70,11 +70,20 @@ class AngularFourierDomain(Domain):
     is_transform_domain = True    
     
 
-class PhasorDomain(Domain):
+class PhasorTimeDomain(Domain):
     domain = 'phasor'
-    domain_label = 'Phasor'
+    domain_label = ''
     domain_units = ''
     is_phasor_domain = True
+    is_transform_domain = True
+
+    
+class PhasorFrequencyDomain(Domain):
+    domain = 'phasor'
+    domain_label = 'Angular Frequency'
+    domain_units = 'rad/s'
+    is_phasor_domain = True
+    is_transform_domain = True            
 
 
 class FourierNoiseDomain(Domain):
