@@ -29,6 +29,7 @@ import numpy as np
 import sympy as sym
 from sympy.utilities.lambdify import lambdify
 from .sym import simplify
+from .simplify import simplify_sin_cos
 from collections import OrderedDict
 
 __all__ = ('expr', 'symbol', 'symbols')
@@ -217,7 +218,7 @@ class ExprTuple(ExprPrint, tuple, ExprContainer, ExprMisc):
 
     
 class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
-    """Decorator class for sympy classes derived from sympy.Expr"""
+    """Decorator class for sympy classes derived from sympy.Expr."""
 
     var = None
 
@@ -267,6 +268,8 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
                     ('constant', 'admittance'): 'impedance',
                     ('constant', 'transfer'): 'transfer',
                     ('constant', 'constant'): 'constant',
+                    ('impedance', 'impedance'): 'transfer',
+                    ('admittance', 'admittance'): 'transfer',                                        
                     ('voltagesquared', 'voltage'): 'voltage',
                     ('currentsquared', 'current'): 'current',
                     ('admittancesquared', 'admittance'): 'admittance',
@@ -357,6 +360,8 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
             return self.as_admittance()
         elif quantity == 'transfer':
             return self.as_transfer()
+        elif quantity == 'power':
+            return self.as_power()
         elif quantity == 'undefined':
             return self.as_expr(expr)        
         raise ValueError('Unknown quantity %s for %s' % (quantity, self))
@@ -388,8 +393,11 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
         return self._class_by_quantity('impedance')(self)
 
     def as_transfer(self):
-        return self._class_by_quantity('transfer')(self)    
-    
+        return self._class_by_quantity('transfer')(self)
+
+    def as_power(self):
+        return self._class_by_quantity('power')(self)
+
     def as_expr(self):
         return self
 
@@ -566,6 +574,34 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
         
         return self._ratfun.is_strictly_proper
 
+    @property
+    def is_phase(self):
+        return self.part == 'phase'
+
+    @property
+    def is_phase_radians(self):
+        return self.part == 'phase' and self.units == 'rad'
+
+    @property
+    def is_phase_degrees(self):
+        return self.part == 'phase' and self.units == 'degrees'
+
+    @property
+    def is_real_part(self):
+        return self.part == 'real'
+
+    @property
+    def is_imag_part(self):
+        return self.part == 'imaginary'
+
+    @property
+    def is_magnitude(self):
+        return self.part == 'magnitude'
+
+    @property
+    def is_dB(self):
+        return self.part == 'magnitude' and self.units == 'dB'
+    
     @property
     def fval(self):
         """Evaluate expression and return as a python float value."""
@@ -637,7 +673,7 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
             a = getattr(expr1, attr)
         except:
             raise
-            
+
         # This gets called if there is no explicit attribute attr for
         # this instance.  We call the method of the wrapped sympy
         # class and rewrap the returned value if it is a sympy Expr
@@ -779,9 +815,9 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
                 return cls, self, x, assumptions
 
         # For phasor comparisons...
-        if self.is_phasor_frequency_domain and x.is_angular_fourier_domain:
+        if self.is_phasor_domain and x.is_angular_fourier_domain:
             return cls, self, cls(x), assumptions
-        if self.is_angular_fourier_domain and x.is_phasor_frequency_domain:
+        if self.is_angular_fourier_domain and x.is_phasor_domain:
             return xcls, cls(self), x, assumptions        
 
         if not self._add_compatible_domains(x):
@@ -797,7 +833,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         self._incompatible_quantities(x, op)        
 
     def __mul__(self, x):
-        """Multiply"""
+        """Multiply."""
 
         from .super import Superposition
 
@@ -848,7 +884,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         if quantity == 'constant':
             quantity = 'undefined'
 
-        if self.__class__ == ConstantExpression:
+        if self.is_constant_domain:
             cls = x._class_by_quantity(quantity)
         else:
             cls = self._class_by_quantity(quantity)
@@ -856,12 +892,12 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return cls(self.expr * x.expr, **assumptions)
     
     def __rmul__(self, x):
-        """Reverse multiply"""
+        """Reverse multiply."""
 
         return self.__mul__(x)
 
     def __truediv__(self, x):
-        """Divide"""
+        """True divide."""
 
         if not isinstance(x, Expr):
             x = expr(x)
@@ -894,7 +930,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         if quantity == 'constant':
             quantity = 'undefined'
 
-        if self.__class__ == ConstantExpression:            
+        if self.is_constant_domain:
             cls = x._class_by_quantity(quantity)
         else:
             cls = self._class_by_quantity(quantity)
@@ -902,7 +938,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return cls(self.expr / x.expr, **assumptions)            
             
     def __rtruediv__(self, x):
-        """Reverse true divide"""
+        """Reverse true divide."""
 
         from .matrix import Matrix
         
@@ -915,7 +951,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return x.__truediv__(self)
             
     def __add__(self, x):
-        """Add"""
+        """Add."""
 
         from .matrix import Matrix
 
@@ -926,27 +962,27 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return cls(self.expr + x.expr, **assumptions)
 
     def __radd__(self, x):
-        """Reverse add"""
+        """Reverse add."""
 
         if not isinstance(x, Expr):
             x = expr(x)
         return x.__add__(self)
 
     def __sub__(self, x):
-        """Subtract"""
+        """Subtract."""
 
         cls, self, x, assumptions = self.__compat_add__(x, '-')
         return cls(self.expr - x.expr, **assumptions)
 
     def __rsub__(self, x):
-        """Reverse subtract"""
+        """Reverse subtract."""
 
         if not isinstance(x, Expr):
             x = expr(x)
         return x.__sub__(self)        
 
     def __pow__(self, x):
-        """Power"""
+        """Power."""
 
         if x == 2:
             return self.__mul__(self)
@@ -959,12 +995,12 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
             x = expr(x)
 
         result = self.expr.__pow__(x.expr)
-        if (self.__class__ != ConstantExpression):
+        if not self.is_constant_domain:
             return self.__class__(result)
         return x.__class__(result)        
     
     def __rpow__(self, x):
-        """Reverse pow, x**self"""
+        """Reverse pow, x**self."""
 
         if not isinstance(x, Expr):
             x = expr(x)
@@ -972,7 +1008,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return x.__pow__(self)
 
     def __or__(self, x):
-        """Parallel combination"""
+        """Parallel combination."""
 
         return self.parallel(x)
 
@@ -1023,7 +1059,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return sym.simplify(self.expr - x.expr) != 0        
 
     def __gt__(self, x):
-        """Greater than"""
+        """Greater than."""
 
         if x is None:
             return True
@@ -1034,7 +1070,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return self.expr > x.expr
 
     def __ge__(self, x):
-        """Greater than or equal"""
+        """Greater than or equal."""
 
         if x is None:
             return True
@@ -1045,7 +1081,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return self.expr >= x.expr
 
     def __lt__(self, x):
-        """Less than"""
+        """Less than."""
 
         if x is None:
             return True
@@ -1056,7 +1092,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return self.expr < x.expr
 
     def __le__(self, x):
-        """Less than or equal"""
+        """Less than or equal."""
 
         if x is None:
             return True
@@ -1067,7 +1103,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         return self.expr <= x.expr
 
     def parallel(self, x):
-        """Parallel combination"""
+        """Parallel combination."""
 
         cls, self, x, assumptions = self.__compat_add__(x, '|')
         x = cls(x)
@@ -1080,9 +1116,9 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
     @property
     def conjugate(self):
-        """Return complex conjugate."""
+         """Return complex conjugate."""
 
-        return self.__class__(sym.conjugate(self.expr), **self.assumptions)
+         return self.__class__(sym.conjugate(self.expr), **self.assumptions)
 
     @property
     def real(self):
@@ -1112,7 +1148,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
     @property
     def real_imag(self):
-        """Rewrite as x + j * y"""
+        """Rewrite as x + j * y."""
 
         return self.real + j * self.imag
 
@@ -1196,14 +1232,14 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         from .utils import factor_const
 
         c, r = factor_const(self, self.var)
-        return ConstantExpression(c), self.__class__(r, **self.assumptions)
+        return ConstantDomainExpression(c), self.__class__(r, **self.assumptions)
 
     def term_const(self):
 
         from .utils import term_const
 
         c, r = term_const(self, self.var)
-        return ConstantExpression(c), self.__class__(r, **self.assumptions)    
+        return ConstantDomainExpression(c), self.__class__(r, **self.assumptions)    
 
     def multiply_top_and_bottom(self, factor):
         """Multiply numerator and denominator by common factor."""
@@ -1220,7 +1256,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
     
     @property
     def magnitude(self):
-        """Return magnitude"""
+        """Return magnitude."""
 
         if self.is_real:
             dst = expr(abs(self.expr))
@@ -1238,13 +1274,13 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
     @property
     def abs(self):
-        """Return magnitude"""
+        """Return magnitude."""
 
         return self.magnitude
 
     @property
     def sign(self):
-        """Return sign"""
+        """Return sign."""
 
         return self.__class__(sym.sign(self.expr), **self.assumptions)
 
@@ -1263,6 +1299,9 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
     def phase(self):
         """Return phase in radians."""
 
+        if self.is_time_domain or self.is_discrete_time_domain:
+            raise ValueError('Cannot determine phase of time-domain expression %s' % self)
+        
         R = self.rationalize_denominator()
         N = R.N
 
@@ -1276,7 +1315,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
                 G = gcd(N.real, N.imag)
                 N = N / G
             dst = atan2(N.imag, N.real)
-            
+
         dst.part = 'phase'
         dst.units = 'rad'
         return dst
@@ -1292,37 +1331,37 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
     @property
     def angle(self):
-        """Return phase angle"""
+        """Return phase angle (in radians)."""
 
         return self.phase
 
     @property
     def polar(self):
-        """Return in polar format"""
+        """Return in polar format."""
 
         return self.abs * exp(j * self.phase)
 
     @property
     def cartesian(self):
-        """Return in Cartesian format"""
+        """Return in Cartesian format."""
 
         return self.real + j * self.imag
     
     @property
     def is_number(self):
-        """Returns True if expression is a number"""                
+        """Returns True if expression is a number."""                
 
         return self.expr.is_number
 
     @property
     def is_constant(self):
-        """Returns True if expression does not have any free symbols  (compare with `is_unchanging`)"""        
+        """Returns True if expression does not have any free symbols  (compare with `is_unchanging`)."""        
 
         return self.expr.free_symbols == set()
 
     @property
     def is_unchanging(self):
-        """Returns True if expression does not have a domain variable (compare with `is_constant`)"""
+        """Returns True if expression does not have a domain variable (compare with `is_constant`)."""
 
         return self.var not in self.expr.free_symbols
     
@@ -1626,6 +1665,12 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         result = 0
         for factor in self.expr.factor().as_ordered_factors():
             result *= symsimplify(factor)
+        return self.__class__(result, **self.assumptions)
+
+    def simplify_sin_cos(self, as_cos=False, as_sin=False):
+        """Simplify c * cos(theta) - s * sin(theta) as A * cos(theta - phi)."""
+
+        result = simplify_sin_cos(self.expr, as_cos, as_sin)
         return self.__class__(result, **self.assumptions)        
 
     def replace(self, query, value, map=False, simultaneous=True, exact=None):
@@ -1669,10 +1714,10 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         label = ''
         if hasattr(self, 'quantity_label'):
             label += self.quantity_label
-            if hasattr(self, 'part'):
+            if self.part != '':
                 label += ' ' + self.part
         else:
-            if hasattr(self, 'part'):
+            if self.part != '':
                 label += capitalize_name(self.part)
         return label
 
@@ -2407,7 +2452,7 @@ def symbols(names, **assumptions):
     return symbols
 
 
-from .cexpr import cexpr, ConstantExpression
+from .cexpr import cexpr, ConstantDomainExpression
 from .fexpr import f, fexpr, FourierDomainExpression
 from .texpr import t, texpr, TimeDomainExpression
 from .sexpr import s, sexpr, LaplaceDomainExpression
