@@ -118,14 +118,7 @@ def fexpr(arg, **assumptions):
 
 
 from .expressionclasses import expressionclasses
-classes = expressionclasses.make(FourierDomainExpression)
 
-FourierDomainVoltage = classes['voltage']
-FourierDomainCurrent = classes['current']
-expressionclasses.add('fourier', classes)
+classes = expressionclasses.register('fourier', FourierDomainExpression)
 
-from .texpr import TimeDomainExpression
-from .sexpr import LaplaceDomainExpression
-from .omegaexpr import AngularFourierDomainExpression
-from .cexpr import ConstantExpression
 f = FourierDomainExpression('f')
