@@ -1,5 +1,5 @@
 """This module provides support for Fourier transforms.  It acts as a
-wrapper for SymPy's Fourier transform.  It calculates the bilateral
+quantity for SymPy's Fourier transform.  It calculates the bilateral
 Fourier transform using:
 
    S(f) = \int_{-\infty}^{\infty} s(t) e^{-j * 2 * \pi * t} dt
@@ -9,7 +9,7 @@ by using Dirac deltas.  For example, a, cos(a * t), sin(a * t), exp(j
 * a * t).
 
 
-Copyright 2016--2020 Michael Hayes, UCECE
+Copyright 2016--2021 Michael Hayes, UCECE
 
 """
 
@@ -21,6 +21,7 @@ Copyright 2016--2020 Michael Hayes, UCECE
 import sympy as sym
 from .sym import sympify, AppliedUndef, j, pi, symsimplify
 from .utils import factor_const, scale_shift
+from .extrafunctions import rect, sinc
 
 __all__ = ('FT', 'IFT')
 
@@ -140,7 +141,7 @@ def fourier_term(expr, t, f, inverse=False):
     const1 = const
     other = one
     exps = one
-    factors = expr.as_ordered_factors()    
+    factors = expr.expand().as_ordered_factors()    
     for factor in factors:
         if not factor.has(t):
             const1 *= factor
@@ -154,9 +155,31 @@ def fourier_term(expr, t, f, inverse=False):
     
     if other != 1 and exps == 1:
         if other == t:
-            return const1 * sym.I * 2 * sym.pi * f * sym.DiracDelta(f, 1)
-        if other == t**2:
-            return const1 * (sym.I * 2 * sym.pi)**2 * sym.DiracDelta(f, 2)
+            return const1 * sym.I / (2 * sym.pi) * sym.DiracDelta(sf, 1)
+        elif other == t**2:
+            return -const1 / (2 * sym.pi)**2 * sym.DiracDelta(sf, 2)
+        # TODO check for other powers of t...
+        elif other == sym.sign(t):
+            return const1 / (sym.I * sym.pi * sf)
+        elif other == sym.sign(t) * t:
+            return -const1 * 2 / (2 * sym.pi * f)**2
+        elif other == sym.Heaviside(t):
+            return const1 / (sym.I * 2 * sym.pi * f) + const1 * sym.DiracDelta(sf) / 2
+        elif other == 1 / t:
+            return -const1 * sym.I * sym.pi * sym.sign(sf)
+        elif other == 1 / t**2:
+            return -const1 * 2 * sym.pi**2 * sf * sym.sign(sf)        
+        elif other.is_Function and other.func == sym.Heaviside and other.args[0].has(t):
+            # TODO, generalise use of similarity and shift theorems for other functions and expressions
+            scale, shift = scale_shift(other.args[0], t)
+            return (const1 / (sym.I * 2 * sym.pi * sf / scale) / abs(scale) + const1 * sym.DiracDelta(sf) / 2) * sym.exp(sym.I * 2 * sym.pi * sf /scale * shift)
+        elif other == sym.Heaviside(t) * t:
+            return -const1 / (2 * sym.pi * f)**2 + const1 * sym.I * sym.DiracDelta(sf, 1) / (4 * pi)
+        elif other.is_Function and other.func == sinc and other.args[0].has(t):
+            scale, shift = scale_shift(other.args[0], t)            
+            return const1 * rect(sf / scale) * sym.exp(sym.I * 2 * sym.pi * sf /scale * shift) / abs(scale)
+        elif other.is_Function and other.func == rect and other.args[0].has(t):        
+            return const1 * sinc(sf / scale) * sym.exp(sym.I * 2 * sym.pi * sf /scale * shift) / abs(scale)
 
         # Sympy incorrectly gives exp(-a * t) instead of exp(-a * t) *
         # Heaviside(t)
