@@ -24,7 +24,11 @@ class Function(object):
         result = self.expr(*tweak_args)
 
         if isinstance(args[0], Expr):
+
             result = cls(result)
+            if args[0].is_phase and self.expr in (sym.sin, sym.cos, sym.tan, sym.exp,
+                                                  sym.sinh, sym.cosh, sym.tanh):
+                result.part = ''
 
         if False:
             for m, arg in enumerate(args[1:]):
