@@ -5,16 +5,17 @@ Copyright 2020 Michael Hayes, UCECE
 
 """
 
-from .omegaexpr import omegaExpr, Zomega, Yomega
-from .sexpr import Zs, Ys
-from .symbols import j, omega, jomega, s
-
 class ImmittanceMixin(object):
 
     @property
     def R(self):
         """Resistance."""
-        return Resistance(self.Zw.real)
+        from .symbols import s
+        
+        ret = self.Z.real
+        if self.is_causal:
+            ret = ret.replace(s.real, 0)
+        return ret
 
     @property
     def resistance(self):
@@ -24,7 +25,7 @@ class ImmittanceMixin(object):
     @property
     def X(self):
         """Reactance."""
-        return Reactance(self.Zw.imag)
+        return self.Z.imag
 
     @property
     def reactance(self):
@@ -43,7 +44,12 @@ class ImmittanceMixin(object):
         not infinity as might be expected.
 
         """
-        return Conductance(self.Yw.real)
+        from .symbols import s
+        
+        ret = self.Y.real
+        if self.is_causal:
+            ret = ret.replace(s.real, 0)
+        return ret        
 
     @property
     def conductance(self):
@@ -53,45 +59,37 @@ class ImmittanceMixin(object):
     @property
     def B(self):
         """Susceptance."""
-        return Susceptance(-self.Yw.imag)
-
-    @property
-    def susceptance(self):
-        """Susceptance."""
-        return self.B
+        return -self.Y.imag
 
     @property
     def Y(self):
-        """Admittance."""
+        """Admittance.
+
+        The admittance is expressed in jomega form for AC circuits
+        and in s-domain for for transient circuits.
+        
+        Use Y(omega) or Y(s) to achieve the desired form."""
+        
         return self.admittance
 
     @property
     def Z(self):
-        """Impedance."""
-        return self.impedance
+        """Impedance.
 
-    @property
-    def Yw(self):
-        """Admittance  Y(omega)."""
-        return Yomega(self.admittance._selectexpr(omega))
+        The impedance is expressed in jomega form for AC circuits
+        and in s-domain for for transient circuits.  
 
-    @property
-    def Zw(self):
-        """Impedance  Z(omega)."""
-        return Zomega(self.impedance._selectexpr(omega))
+        Use Z(omega) or Z(s) to achieve the desired form."""
 
-    @property
-    def Ys(self):
-        """Generalized admittance  Y(s)."""
-        return Ys(self.admittance._selectexpr(s))
+        return self.impedance    
 
-    @property
-    def Zs(self):
-        """Generalized impedance  Z(s)."""
-        return Zs(self.impedance._selectexpr(s))
+    def network(self, form='default'):
+        """Synthesise a network with an equivalent impedance.
+        `form` includes: cauerI, cauerII, fosterI, fosterII.
 
-from .resistance import Resistance
-from .reactance import Reactance
-from .conductance import Conductance
-from .susceptance import Susceptance
+        Note some methods generate networks with negative value
+        components."""
 
+        from .synthesis import network
+        
+        return network(self.Z, form)
