@@ -8,13 +8,13 @@ Copyright 2015--2020 Michael Hayes, UCECE
 
 from __future__ import print_function
 from .expr import expr
-from .cexpr import ConstantExpression
+from .cexpr import ConstantDomainExpression
 from .omegaexpr import AngularFourierDomainExpression
 from .symbols import j, omega, jomega, s, t
 from .functions import sqrt
 from .sym import capitalize_name, omegasym
 from .grammar import delimiters
-from .immittancemixinhack import ImmittanceMixinHack
+from .immittancemixin import ImmittanceMixin
 from .superpositioncurrent import SuperpositionCurrent
 from .opts import Opts
 import lcapy
@@ -30,7 +30,7 @@ cptaliases = {'E': 'VCVS', 'F': 'CCCS',
               'k': 'Spring'}
 
 
-class Cpt(ImmittanceMixinHack):
+class Cpt(ImmittanceMixin):
 
     dependent_source = False
     independent_source = False    
@@ -315,9 +315,9 @@ class Cpt(ImmittanceMixinHack):
     @property
     def _source_IV(self):
 
-        if self.cpt.voltage_source:
+        if self.cpt.is_voltage_source:
             return self.cpt.Voc
-        elif self.cpt.current_source:
+        elif self.cpt.is_current_source:
             return self.cpt.Isc
         else:
             raise ValueError('%s is not a source' % self)        
@@ -383,9 +383,9 @@ class Cpt(ImmittanceMixinHack):
     def is_noisy(self):
         """Return True if source is noisy."""
 
-        if self.cpt.voltage_source:
+        if self.cpt.is_voltage_source:
             return self.cpt.is_noisy
-        elif self.cpt.current_source:
+        elif self.cpt.is_current_source:
             return self.cpt.is_noisy
         else:
             raise ValueError('%s is not a source' % self)        
@@ -393,12 +393,12 @@ class Cpt(ImmittanceMixinHack):
     @property
     def is_inductor(self):
         """Return True if component is an inductor."""
-        return self.cpt.inductor
+        return self.cpt.is_inductor
 
     @property
     def is_capacitor(self):
         """Return True if component is a capacitor."""
-        return self.cpt.capacitor
+        return self.cpt.is_capacitor
 
     @property
     def is_reactance(self):
@@ -408,19 +408,24 @@ class Cpt(ImmittanceMixinHack):
     @property
     def is_resistor(self):
         """Return True if component is a resistor."""
-        return self.cpt.resistor        
+        return self.cpt.is_resistor
+
+    @property
+    def is_conductor(self):
+        """Return True if component is a conductor."""
+        return self.cpt.is_conductor            
 
     @property
     def is_voltage_source(self):
         """Return True if component is a voltage source (dependent or
         independent)"""
-        return self.cpt.voltage_source    
+        return self.cpt.is_voltage_source    
 
     @property
     def is_current_source(self):
         """Return True if component is a current source (dependent or
         independent)"""
-        return self.cpt.current_source    
+        return self.cpt.is_current_source    
         
     @property
     def zeroic(self):
@@ -611,6 +616,16 @@ class Cpt(ImmittanceMixinHack):
         
         return self.cct.norton(self.nodenames[1], self.nodenames[0])
 
+    def transfer(self, cpt):
+        """Create transfer function for the s-domain voltage across the
+        specified cpt divided by the s-domain voltage across self."""
+
+        if isinstance(cpt, str):
+            cpt = self.cct._elements[cpt]        
+        
+        return self.cct.transfer(self.nodenames[1], self.nodenames[0],
+                                 cpt.nodenames[1], cpt.nodenames[0])
+
     @property
     def nodes(self):
         """Return list of nodes for this component.   See also
@@ -903,9 +918,9 @@ class VCVS(DependentSource):
             cct._B[n2, m] -= 1
             cct._C[m, n2] -= 1
 
-        Ad = ConstantExpression(self.args[0]).expr
+        Ad = ConstantDomainExpression(self.args[0]).expr
         if len(self.args) > 1:
-            Ac = ConstantExpression(self.args[1]).expr
+            Ac = ConstantDomainExpression(self.args[1]).expr
         else:
             Ac = 0
 
@@ -933,7 +948,7 @@ class CCCS(DependentSource):
     def _stamp(self, cct):
         n1, n2 = self.node_indexes
         m = cct._branch_index(self.args[0])
-        F = ConstantExpression(self.args[1]).expr
+        F = ConstantDomainExpression(self.args[1]).expr
             
         if n1 >= 0:
             cct._B[n1, m] -= F
@@ -958,7 +973,7 @@ class VCCS(DependentSource):
 
     def _stamp(self, cct):
         n1, n2, n3, n4 = self.node_indexes
-        G = ConstantExpression(self.args[0]).expr
+        G = ConstantDomainExpression(self.args[0]).expr
 
         if n1 >= 0 and n3 >= 0:
             cct._G[n1, n3] -= G
@@ -1000,7 +1015,7 @@ class GY(Dummy):
         # V2 = -I1 Z2     V1 = I2 Z1
         # where V2 = V[n1] - V[n2] and V1 = V[n3] - V[n4]
         
-        Z1 = ConstantExpression(self.args[0]).expr                    
+        Z1 = ConstantDomainExpression(self.args[0]).expr                    
         Z2 = Z1
         
         if n1 >= 0:
@@ -1038,7 +1053,7 @@ class CCVS(DependentSource):
             cct._C[m, n2] -= 1
         
         mc = cct._branch_index(self.args[0])
-        G = ConstantExpression(self.args[1]).expr
+        G = ConstantDomainExpression(self.args[1]).expr
         cct._D[m, mc] -= G
 
     def _kill(self):
@@ -1407,7 +1422,7 @@ class TR(Dummy):
             cct._B[n2, m] += 1
             cct._C[m, n2] += 1
         
-        A = ConstantExpression(self.args[0]).expr
+        A = ConstantDomainExpression(self.args[0]).expr
         
         if n1 >= 0:
             cct._C[m, n1] -= A
