@@ -99,14 +99,10 @@ def omegaexpr(arg, **assumptions):
 
 
 from .expressionclasses import expressionclasses
-classes = expressionclasses.make(AngularFourierDomainExpression)
-expressionclasses.add('angular fourier', classes)
 
-AngularFourierDomainAdmittance = classes['admittance']
-AngularFourierDomainImpedance = classes['impedance']
+classes = expressionclasses.register('angular fourier', AngularFourierDomainExpression)
         
-from .texpr import TimeDomainExpression
-from .sexpr import LaplaceDomainExpression
-from .cexpr import ConstantExpression
 omega = AngularFourierDomainExpression('omega')
-omega0 = AngularFourierDomainExpression('omega_0')
+# This represents a specific angular frequency and is assumed to be positive
+omega0 = AngularFourierDomainExpression('omega_0', positive=True)
+
