@@ -140,11 +140,11 @@ class OnePort(Network, ImmittanceMixin):
 
     @property
     def has_series_I(self):
-        return self.current_cource
+        return self.is_current_source
 
     @property    
     def has_parallel_V(self):
-        return self.voltage_source
+        return self.is_voltage_source
     
     def series(self, OP):
         """Series combination"""
@@ -770,9 +770,9 @@ class Ser(ParSer):
 class R(OnePort):
     """Resistor"""
 
-    resistor = True    
+    is_resistor = True    
     
-    def __init__(self, Rval):
+    def __init__(self, Rval='R'):
 
         self.args = (Rval, )
         self._R = cexpr(Rval)
@@ -788,11 +788,11 @@ class R(OnePort):
     
 
 class G(OnePort):
-    """Conductance"""
+    """Conductor"""
 
-    resistor = True    
+    is_conductor = True    
 
-    def __init__(self, Gval):
+    def __init__(self, Gval='G'):
 
         self.args = (Gval, )
         self._G = cexpr(Gval)
@@ -820,9 +820,9 @@ class L(OnePort):
 
     Inductance Lval, initial current i0"""
 
-    inductor = True
+    is_inductor = True
 
-    def __init__(self, Lval, i0=None):
+    def __init__(self, Lval='L', i0=None):
 
         self.has_ic = i0 is not None
         if i0 is None:
@@ -863,9 +863,9 @@ class C(OnePort):
 
     Capacitance Cval, initial voltage v0"""
 
-    capacitor = True    
+    is_capacitor = True    
 
-    def __init__(self, Cval, v0=None):
+    def __init__(self, Cval='C', v0=None):
 
         self.has_ic = v0 is not None
         if v0 is None:
@@ -949,7 +949,7 @@ class Z(OnePort):
 
 class VoltageSourceBase(OnePort):
 
-    voltage_source = True
+    is_voltage_source = True
     netname = 'V'
     is_noisy = False
 
@@ -973,7 +973,7 @@ class sV(VoltageSourceBase):
 class V(VoltageSourceBase):
     """Arbitrary voltage source"""
 
-    def __init__(self, Vval):
+    def __init__(self, Vval='V'):
 
         self.args = (Vval, )
         self._Voc = SuperpositionVoltage(Vval)
@@ -1041,8 +1041,8 @@ class Vac(VoltageSourceBase):
         self.omega = omega
         self.v0 = V
         self.phi = phi
-        self._Voc = SuperpositionVoltage(PhasorDomainVoltage(self.v0 * exp(j * self.phi),
-                                                             ac=True, omega=self.omega))
+        self._Voc = SuperpositionVoltage(phasor(self.v0 * exp(j * self.phi),
+                                                omega=self.omega))
 
     @property
     def voc(self):
@@ -1074,7 +1074,7 @@ class v(VoltageSourceBase):
 
 class CurrentSourceBase(OnePort):
 
-    current_source = True
+    is_current_source = True
     netname = 'I'
     is_noisy = False    
 
@@ -1104,7 +1104,7 @@ class sI(CurrentSourceBase):
 class I(CurrentSourceBase):
     """Arbitrary current source"""
 
-    def __init__(self, Ival):
+    def __init__(self, Ival='I'):
 
         self.args = (Ival, )
         self._Isc = SuperpositionCurrent(Ival)
@@ -1170,8 +1170,8 @@ class Iac(CurrentSourceBase):
         self.omega = omega
         self.i0 = I
         self.phi = phi
-        self._Isc = SuperpositionCurrent(PhasorDomainCurrent(self.i0 * exp(j * self.phi),
-                                                       ac=True, omega=self.omega))
+        self._Isc = SuperpositionCurrent(phasor(self.i0 * exp(j * self.phi),
+                                                omega=self.omega))
 
     @property
     def isc(self):
@@ -1449,9 +1449,9 @@ from .expr import Expr, expr
 from .cexpr import cexpr
 from .sexpr import LaplaceDomainExpression
 from .texpr import TimeDomainExpression
+from .phasor import phasor
 from .noiseomegaexpr import AngularFourierNoiseDomainCurrent, AngularFourierNoiseDomainVoltage
 from .superpositionvoltage import SuperpositionVoltage
 from .superpositioncurrent import SuperpositionCurrent
-from .phasor import PhasorDomainCurrent, PhasorDomainVoltage
 from .twoport import Ladder, LSection, TSection
 
