@@ -28,13 +28,12 @@ Copyright 2014--2021 Michael Hayes, UCECE
 
 from __future__ import division
 from .acdc import ACChecker
-from .domains import PhasorDomain
+from .domains import PhasorTimeDomain, PhasorFrequencyDomain
 from .sym import j, omegasym
 from .expr import expr
 from .functions import sin, cos, exp, sqrt
 from .expr import Expr
-from .cexpr import ConstantExpression
-from .omegaexpr import AngularFourierDomainExpression, omega
+from .omegaexpr import omega
 from .voltagemixin import VoltageMixin
 from .currentmixin import CurrentMixin
 from .admittancemixin import AdmittanceMixin
@@ -57,17 +56,17 @@ __all__ = ('phasor', )
 
 
 
-class PhasorDomainExpression(PhasorDomain, Expr):
+class PhasorExpression(Expr):
 
     def __init__(self, val, **assumptions):
 
-        if isinstance(val, PhasorDomainExpression):
+        if isinstance(val, PhasorExpression):
             assumptions['omega'] = val.omega
-        elif 'omega' not in assumptions:
+        elif 'omega' not in assumptions or assumptions['omega'] is None:
             assumptions['omega'] = omegasym
-
+        
         assumptions['ac'] = True
-        super (PhasorDomainExpression, self).__init__(val, **assumptions)
+        super (PhasorExpression, self).__init__(val, **assumptions)
     
     @property
     def omega(self):
@@ -99,41 +98,27 @@ class PhasorDomainExpression(PhasorDomain, Expr):
 
         return self.time().laplace()
 
-    @property
-    def abs(self):
-        """Return magnitude"""
-
-        return expr(self.expr).abs
-
-    @property
-    def magnitude(self):
-        """Return magnitude"""
-
-        return expr(self.expr).magnitude    
-
-    @property
-    def phase(self):
-        """Return phase in radians."""
-
-        return expr(self.expr).phase
-
-    @property
-    def sign(self):
-        """Return sign."""
-
-        return expr(self.expr).sign
-
     def phasor(self):
         """Convert to phasor representation."""
+        
         return self.__class__(self, **self.assumptions)
 
     def rms(self):
-        return {PhasorDomainVoltage: TimeDomainVoltage,
-                PhasorDomainCurrent : TimeDomainCurrent}[self.__class__](0.5 * self)
+        """Return root mean square."""
+        
+        return abs(self) * sqrt(2) / 2
 
-    def plot(self, **kwargs):
+    def plot(self, wvector=None, **kwargs):
+        """Plot polar diagram for a time-domain phasor or frequency response
+        for frequency-domain phasor.  For the latter, wvector
+        specifies the angular frequencies.  If it is a tuple, it sets
+        the angular frequency limits."""
+        
+        from .plot import plot_phasor, plot_angular_frequency
 
-        from .plot import plot_phasor
+        if self.is_phasor_frequency_domain:
+            return plot_angular_frequency(self, wvector, **kwargs)            
+        
         return plot_phasor(self, **kwargs)
 
     def _mul_compatible(self, x):
@@ -148,14 +133,14 @@ class PhasorDomainExpression(PhasorDomain, Expr):
                          (self.omega, x.omega))
         
 
-class PhasorDomainTimeExpression(PhasorDomainExpression):
+class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
     """This is a phasor domain base class for voltages and currents."""
 
     is_phasor_domain = True
     is_phasor_time_domain = True
 
     def as_expr(self):
-        return PhasorDomainTimeExpression(self)
+        return PhasorTimeDomainExpression(self)
 
     @classmethod
     def from_time(cls, expr, omega=None, **assumptions):
@@ -179,6 +164,10 @@ class PhasorDomainTimeExpression(PhasorDomainExpression):
         
         if omega is not None and check.omega != omega.expr:
             raise ValueError('Expecting omega=%s, found omega=%s.' % (omega, check.omega))
+
+        if check.omega == 0:
+            print('Warning, DC phasor.')
+        
         result = check.amp * exp(j * check.phase)
         assumptions['omega'] = check.omega
 
@@ -201,7 +190,7 @@ class PhasorDomainTimeExpression(PhasorDomainExpression):
         return TimeDomainExpression(result)
     
 
-class PhasorDomainFrequencyExpression(PhasorDomainExpression):
+class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
     """This represents the ratio of two-phasors; for example
     an impedance, an admittance, or a transfer function."""
 
@@ -220,77 +209,51 @@ class PhasorDomainFrequencyExpression(PhasorDomainExpression):
             print('Should convert %s expression to time-domain first' % expr.quantity)
 
         result = expr.laplace(**assumptions).replace(s, j * omega)
-        return cls.change(expr, PhasorDomainFrequencyExpression(result, omega=omega,
+        return cls.change(expr, PhasorFrequencyDomainExpression(result, omega=omega,
                                                                 **assumptions))
     
     def time(self, **assumptions):
         """Convert to time domain representation."""
         from .symbols import s
+        from .sexpr import LaplaceDomainExpression
 
         omega = self.omega
         result = LaplaceDomainExpression(self.replace(j * omega, s))
         return self.change(result.time())
 
     def as_expr(self):
-        return PhasorDomainFrequencyExpression(self)
+        return PhasorFrequencyDomainExpression(self)
     
 
-class PhasorDomainAdmittance(AdmittanceMixin, PhasorDomainFrequencyExpression):
-    """PhasorDomain admittance"""
-    pass
+def phasor(arg, omega=None, **assumptions):
+    """Create phasor.   
 
+    If arg has the form A * cos(w * t + phi) the phasor 
+    A * exp(j * phi) of angular frequency w is returned.
 
-class PhasorDomainImpedance(ImpedanceMixin, PhasorDomainFrequencyExpression):
-    """PhasorDomain impedance"""
-    pass
+    If arg is a constant C, the phasor C is created with omega as the
+    angular frequency (this defaults to 'omega' if not specified).
 
-
-class PhasorDomainTransferFunction(TransferMixin, PhasorDomainFrequencyExpression):
-    """PhasorDomain transfer function response."""
-    pass
-
-    
-class PhasorDomainVoltage(VoltageMixin, PhasorDomainTimeExpression):
-    """Phasor-domain voltage (units V) parameterized as a phasor
-    of a single angular frequency."""
-        
-    def cpt(self):
-        from .oneport import Vac
-        return Vac(self, 0, self.omega)            
-
-    
-class PhasorDomainCurrent(CurrentMixin, PhasorDomainTimeExpression):
-    """Phasor-domain current (units V) parameterized as a phasor
-    of a single angular frequency."""    
-
-    def cpt(self):
-        from .oneport import Iac
-        return Iac(self, 0, self.omega)
-
-
-def phasor(arg, **assumptions):
-    """Create phasor."""
+    """
 
     arg = expr(arg)
 
     if arg.is_time_domain:
-        return PhasorDomainTimeExpression(arg, **assumptions)
+        # Expecting AC signal.
+        return PhasorTimeDomainExpression.from_time(arg, omega=omega, **assumptions)
+    elif arg.is_unchanging:
+        # Expecting phasor (complex amplitude)        
+        return PhasorTimeDomainExpression(arg, omega=omega, **assumptions)
     else:
-        return PhasorDomainFrequencyExpression(arg, **assumptions)
+        # Is this sensible?
+        return PhasorFrequencyDomainExpression(arg, omega=omega, **assumptions)        
     
 
 from .expressionclasses import expressionclasses
 
-classes = expressionclasses.make(PhasorDomainExpression)
-
-classes['voltage'] = PhasorDomainVoltage
-classes['current'] = PhasorDomainCurrent
-classes['admittance'] = PhasorDomainAdmittance
-classes['impedance'] = PhasorDomainImpedance
-classes['transfer'] = PhasorDomainTransferFunction
-expressionclasses.add('phasor', classes)
-
-from .sexpr import LaplaceDomainExpression
-from .texpr import TimeDomainExpression, TimeDomainVoltage, TimeDomainCurrent
+expressionclasses.register('phasor', PhasorTimeDomainExpression,
+                           PhasorFrequencyDomainExpression,
+                           ('voltage', 'current', 'voltagesquared', 'currentsquared'))
+from .texpr import TimeDomainExpression
 from .expr import Expr
 
