@@ -164,7 +164,7 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
     def phasor(self, **assumptions):
         """Convert to phasor domain."""
 
-        result = PhasorDomainFrequencyExpression.from_laplace(self, **assumptions)
+        result = PhasorFrequencyDomainExpression.from_laplace(self, **assumptions)
         return self.change(result, domain='phasor', **assumptions)
 
     def transient_response(self, tvector=None):
@@ -296,7 +296,7 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
 
         return super(LaplaceDomainExpression, self).evaluate(svector)
 
-    def plot(self, t=None, **kwargs):
+    def plot(self, **kwargs):
         """Plot pole-zero map."""
 
         from .plot import plot_pole_zero
@@ -334,10 +334,10 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         """
 
         def def1(defs, symbolname, value):
-            from .cexpr import ConstantExpression
+            from .cexpr import cexpr
             
             sym1 = symbol(symbolname)
-            defs[symbolname] = ConstantExpression(value)
+            defs[symbolname] = cexpr(value)
             return sym1
 
         factors = self.as_ordered_factors()
@@ -468,20 +468,16 @@ def sexpr(arg, **assumptions):
 
 
 from .expressionclasses import expressionclasses
-classes = expressionclasses.make(LaplaceDomainExpression)
 
+classes = expressionclasses.register('laplace', LaplaceDomainExpression)
 LaplaceDomainVoltage = classes['voltage']
 LaplaceDomainCurrent = classes['current']
 LaplaceDomainAdmittance = classes['admittance']
 LaplaceDomainImpedance = classes['impedance']
 LaplaceDomainTransferFunction = classes['transfer']
-expressionclasses.add('laplace', classes)
 
-
-from .texpr import TimeDomainImpulseResponse, TimeDomainAdmittance, TimeDomainImpedance
-from .texpr import TimeDomainExpression, TimeDomainVoltage, TimeDomainCurrent, texpr
-from .cexpr import ConstantExpression
-from .phasor import PhasorDomainFrequencyExpression
+from .texpr import TimeDomainExpression, texpr
+from .phasor import PhasorFrequencyDomainExpression
 
 s = LaplaceDomainExpression('s')
 
