@@ -509,7 +509,6 @@ class LcapyTester(unittest.TestCase):
         R 2 0 1""")
 
         self.assertEqual(a.R.i, 10, "i incorrect")        
-        
 
     def test_K(self):
 
@@ -628,8 +627,6 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual(b.impedance(1, 2), a.impedance(1, 2), "simplify parallel")        
         
-
-
     def test_VRL1_super(self):
         """Lcapy: check VRL circuit
 
@@ -640,3 +637,28 @@ class LcapyTester(unittest.TestCase):
         a.add('R1 4 2 2; right=2')
         a.add('L1 2 3 2; down')
         a.add('W 0 3; right')
+
+    def test_super_nodes(self):
+
+        a = Circuit("""
+        V1 1 2;
+        R1 2 3:
+        R2 1 3""")
+
+        self.assertEqual(a.super_nodes, [['1', '2']], "super_nodes")
+        
+    def test_transfer(self):
+
+        a = Circuit("""
+        V 2 0
+        L 2 1
+        R 1 0""")
+
+        H1 = a.L.transfer('R')
+        H2 = a.transfer(2, 1, 1, 0)
+
+        self.assertEqual(H1, H2, "transfer cpt/nodes")
+        self.assertEqual(H1, -1, "transfer")        
+        
+        
+        
