@@ -1,10 +1,9 @@
 from lcapy import *
-from lcapy.cexpr import ConstantExpression, ConstantVoltage
+from lcapy.cexpr import ConstantDomainExpression
 from lcapy.fexpr import FourierDomainExpression
 from lcapy.omegaexpr import AngularFourierDomainExpression
 from lcapy.texpr import TimeDomainExpression, TimeDomainVoltage
 from lcapy.sexpr import LaplaceDomainVoltage
-from lcapy.phasor import PhasorDomainVoltage, PhasorDomainExpression
 import unittest
 
 
@@ -63,7 +62,7 @@ class LcapyTester(unittest.TestCase):
         """Lcapy: check cExpr1
 
         """
-        a = ConstantExpression('1')
+        a = cexpr('1')
         self.assertEqual2(a.evaluate(), 1, "evaluate incorrect.")
         
         
@@ -315,21 +314,21 @@ class LcapyTester(unittest.TestCase):
 
         """
 
-        c = ConstantExpression(10)
-        self.assertEqual(type(10 + c), ConstantExpression, "Not cExpr")
-        self.assertEqual(type(c + 10), ConstantExpression, "Not cExpr")
-        self.assertEqual(type(ConstantExpression(10) + c), ConstantExpression, "Not cExpr")
-        self.assertEqual(type(c + ConstantExpression(10)), ConstantExpression, "Not cExpr")
+        c = cexpr(10)
+        self.assertEqual(type(10 + c), ConstantDomainExpression, "Not cExpr")
+        self.assertEqual(type(c + 10), ConstantDomainExpression, "Not cExpr")
+        self.assertEqual(type(ConstantDomainExpression(10) + c), ConstantDomainExpression, "Not cExpr")
+        self.assertEqual(type(c + ConstantDomainExpression(10)), ConstantDomainExpression, "Not cExpr")
 
         self.assertEqual(type(10 + s), LaplaceDomainExpression, "Not sExpr")
         self.assertEqual(type(s + 10), LaplaceDomainExpression, "Not sExpr")
-        self.assertEqual(type(ConstantExpression(10) + s), LaplaceDomainExpression, "Not sExpr")
-        self.assertEqual(type(s + ConstantExpression(10)), LaplaceDomainExpression, "Not sExpr")
+        self.assertEqual(type(ConstantDomainExpression(10) + s), LaplaceDomainExpression, "Not sExpr")
+        self.assertEqual(type(s + ConstantDomainExpression(10)), LaplaceDomainExpression, "Not sExpr")
 
         self.assertEqual(type(10 + t), TimeDomainExpression, "Not tExpr")
         self.assertEqual(type(t + 10), TimeDomainExpression, "Not tExpr")
-        self.assertEqual(type(ConstantExpression(10) + t), TimeDomainExpression, "Not tExpr")
-        self.assertEqual(type(t + ConstantExpression(10)), TimeDomainExpression, "Not tExpr")
+        self.assertEqual(type(ConstantDomainExpression(10) + t), TimeDomainExpression, "Not tExpr")
+        self.assertEqual(type(t + ConstantDomainExpression(10)), TimeDomainExpression, "Not tExpr")
 
         v = LaplaceDomainVoltage(10)
         self.assertEqual(type(10 + v), LaplaceDomainVoltage, "Not Vs")
@@ -359,10 +358,11 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual(zp2tf([], [0, -1]), 1 / (s * (s + 1)), "zp2tf")
 
-    def test_rms(self):
+    def test_const_rms(self):
 
-        self.assertEqual(ConstantVoltage(2).rms(), TimeDomainVoltage(2))
-        self.assertEqual(PhasorDomainVoltage(2).rms(), TimeDomainVoltage(1))
+        c = expr(2)
+        
+        self.assertEqual(c.rms(), 2, "const rms")
 
     def test_assumptions(self):
         """Lcapy: check assumptions
@@ -610,29 +610,6 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual(e.fval, a, 'fval')        
 
-    def test_phasor(self):
-
-        a = PhasorDomainExpression(3, omega=7)
-        self.assertEqual(a.omega, 7, 'omega')
-        self.assertEqual(a.phase, 0, 'phase')
-        self.assertEqual(a.magnitude, 3, 'magnitude')        
-        
-        a = PhasorDomainExpression(-3, omega=7)
-        self.assertEqual(a.phase, pi, 'phase')                
-        self.assertEqual(a.magnitude, 3, 'magnitude')
-
-        a = PhasorDomainExpression(-3 + 4j, omega=7)
-        self.assertEqual(a.magnitude, 5, 'magnitude')                        
-
-        v = voltage('cos(5 * t)')
-        i = current('cos(5 * t)')
-        V = v.phasor()
-        I = i.phasor()
-
-        Z = V / I
-        self.assertEqual(Z.is_impedance, True, 'impedance')
-        self.assertEqual(Z.omega, 5, 'omega')
-        
     def test_equality(self):
 
         e = Eq(expr('x(t)'), cos(3 * t))
@@ -640,5 +617,30 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(e.is_dc, False, 'is_dc')
         self.assertEqual(e.is_causal, False, 'is_causal')
         
-               
+    def test_phase(self):
+
+        c = expr(2).phase
+        e = exp(c)        
+        
+        self.assertEqual(c.part, 'phase', "is_phase")
+        self.assertEqual(e.part, '', "exp is_phase")        
+
+    def test_parts(self):
+
+        self.assertEqual(expr(1).real.is_real_part, True, "is_real_part")
+        self.assertEqual(expr(1).imag.is_imag_part, True, "is_imag_part")
+        self.assertEqual(expr(1).magnitude.is_magnitude, True, "is_magnitude")
+        self.assertEqual(expr(1).phase.is_phase, True, "is_phase")
+        self.assertEqual(expr(1).phase_degrees.is_phase_degrees, True, "is_phase_degrees")
+        self.assertEqual(expr(1).dB.is_dB, True, "is_dB")                
+
+    def test_simplify_sin_cos(self):
+
+        a = expr('3 * cos(theta) + 4 * sin(theta)')
+        b = expr('5 * cos(theta - atan(4 / 3))')
+
+        # Note, simplify converts the results to the same form.
+        self.assertEqual(a.simplify_sin_cos(as_cos=True).simplify(), b, "cos form")
+        self.assertEqual(a.simplify_sin_cos(as_sin=True).simplify(), b, "sin form")
+        self.assertEqual(a.simplify_sin_cos().simplify(), b, "default form")        
         
