@@ -33,7 +33,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.is_dc, False, "DC incorrect")
         self.assertEqual(a.is_ac, True, "AC incorrect")
 
-
     def test_VR_dc1(self):
         """Lcapy: check VR dc network
 
@@ -45,7 +44,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.is_ac, False, "AC incorrect")
         self.assertEqual(a.is_dc, True, "DC incorrect")
 
-
     def test_VC_dc1(self):
         """Lcapy: check VC dc network
 
@@ -57,7 +55,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.is_ac, False, "AC incorrect")
         self.assertEqual(a.is_dc, True, "DC incorrect")
 
-
     def test_VC_dc2(self):
         """Lcapy: check VC dc network
 
@@ -77,7 +74,7 @@ class LcapyTester(unittest.TestCase):
         
         self.assertEqual(a.norton().isc, TimeDomainCurrent(-2 * omega0 * sin(omega0 * t)),
                          "Isc incorrect")
-        self.assertEqual(a.thevenin().isc,  TimeDomainCurrent(-2 * omega0 * sin(omega0 * t)),
+        self.assertEqual(a.thevenin().isc, TimeDomainCurrent(-2 * omega0 * sin(omega0 * t)),
                          "Isc incorrect")
         
     def test_superposition(self):
@@ -109,7 +106,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.is_causal, True, "causal fail")
         self.assertEqual(a.Isc.is_causal, True, "causal fail")        
         
-        
     def test_YZ(self):
 
         a = R(1) + V(2) + R(3)
@@ -119,3 +115,12 @@ class LcapyTester(unittest.TestCase):
         b = (R(1) + V(2)) | R(3)
         self.assertEqual(b.Z, expr('3 / 4'), "par Z")
         self.assertEqual(b.Y, expr('4 / 3'), "par Y")                        
+
+    def test_attrs(self):
+
+        self.assertEqual(R(1).is_resistor, True, "is_resistor")
+        self.assertEqual(G(1).is_conductor, True, "is_conductor")
+        self.assertEqual(C(1).is_capacitor, True, "is_capacitor")
+        self.assertEqual(L(1).is_inductor, True, "is_inductor")
+        self.assertEqual(I(1).is_current_source, True, "is_current_source")
+        self.assertEqual(V(1).is_voltage_source, True, "is_voltage_source")                                        
