@@ -74,7 +74,9 @@ class TimeDomainExpression(TimeDomain, Expr):
     def phasor(self, **assumptions):
         """Convert to phasor domain."""
 
-        return PhasorDomainTimeExpression.from_time(self, **assumptions)
+        from .phasor import PhasorTimeDomainExpression
+        
+        return PhasorTimeDomainExpression.from_time(self, **assumptions)
 
     def FT(self, evaluate=True, **assumptions):
         """Attempt Fourier transform.  This is an alias for fourier.
@@ -191,24 +193,6 @@ class TimeDomainExpression(TimeDomain, Expr):
         return self.__class__(result, **assumptions)
 
     
-class TimeDomainAdmittance(TimeDomainExpression):
-    """Time-domain 'admittance' value."""
-
-    quantity = 'admittance'
-    quantity_label = 'Admittance'
-    units = 'siemens/s'
-    is_impedance = True    
-
-
-class TimeDomainImpedance(TimeDomainExpression):
-    """Time-domain 'impedance' value."""
-
-    quantity = 'impedance'
-    quantity_label = 'Impedance'
-    units = 'ohms/s'
-    is_impedance = True
-
-
 class TimeDomainImpulseResponse(TimeDomainExpression):
     """Time-domain impulse response."""
 
@@ -229,19 +213,8 @@ def texpr(arg, **assumptions):
 
 from .expressionclasses import expressionclasses
 
-classes = expressionclasses.make(TimeDomainExpression)
-classes['admittance'] = TimeDomainAdmittance
-classes['impedance'] = TimeDomainImpedance
-classes['transfer'] = TimeDomainImpulseResponse
-
+classes = expressionclasses.register('time', TimeDomainExpression)
 TimeDomainVoltage = classes['voltage']
 TimeDomainCurrent = classes['current']
-expressionclasses.add('time', classes)
-
-from .sexpr import LaplaceDomainExpression
-from .fexpr import FourierDomainExpression
-from .omegaexpr import AngularFourierDomainExpression
-from .cexpr import ConstantExpression
-from .phasor import PhasorDomainTimeExpression
 
 t = TimeDomainExpression('t')
